package com.example.union_ad_ssgf

import android.annotation.SuppressLint
import android.app.Activity
import android.content.Intent
import android.util.Log
import com.example.union_ad_ssgf.config.UnionADConfig
import com.example.union_ad_ssgf.page.AdSplashActivity
import com.qq.e.comm.managers.GDTAdSdk
import com.qq.e.comm.managers.setting.GlobalSetting.setPersonalizedState
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.EventChannel.EventSink
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel


class PluginDelegate(var activity: Activity, pluginBinding: FlutterPluginBinding) :
    MethodChannel.MethodCallHandler, EventChannel.StreamHandler {

    private val TAG = PluginDelegate::class.java.getSimpleName()

    // Flutter 插件绑定对象
    private var bind = pluginBinding

    // 事件通道
    private var eventSink: EventSink? = null

    /*初始化代码块*/
    init {
        _instance = this
    }

    companion object {
        // 插件代理对象
        @SuppressLint("StaticFieldLeak")
        private lateinit var _instance: PluginDelegate
        fun getInstance(): PluginDelegate {
            return _instance
        }
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        val method = call.method
        Log.d(TAG, "MethodChannel onMethodCall method:" + method + " arguments:" + call.arguments)
        when (method) {
            // 获取当前版本
            "getPlatformVersion" -> {
                getPlatformVersion(call, result)
            }
            // 初始化
            "initAd" -> {
                initAd(call, result)
            }
            // 设置广告个性化
            "setPersonalizedState" -> {
                setPersonalizedState(call, result)
            }
            // 开屏广告
            "showSplashAd" -> {
                showSplashAd(call, result)
            }
            // 激励广告
            "showRewardVideoAd" -> {

            }
            // 错误桥接
            else -> {
                result.notImplemented()
            }
        }
    }

    override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
        Log.d(TAG, "EventChannel onListen arguments:" + arguments)
        eventSink = events
    }

    /**
     * 取消事件通道监听
     * @param arguments 参数
     */
    override fun onCancel(arguments: Any?) {
        Log.d(TAG, "EventChannel onCancel")
        eventSink = null
    }

    /**
     * 获取当前版本
     * @param call MethodCall
     * @param result Result
     */
    private fun getPlatformVersion(call: MethodCall, result: MethodChannel.Result) {
        result.success(" Union AD Android " + android.os.Build.VERSION.RELEASE);
    }

    /**
     * 初始化广告
     * @param call   MethodCall
     * @param result Result
     */
    private fun initAd(call: MethodCall, result: MethodChannel.Result) {
        val appId = call.argument<String>("appId")
        GDTAdSdk.initWithoutStart(activity.applicationContext, appId) // 该接口不会采集用户信息
        // 调用initWithoutStart后请尽快调用start，否则可能影响广告填充，造成收入下降
        GDTAdSdk.start(
            object : GDTAdSdk.OnStartListener {
                override fun onStartSuccess() {
                    // 推荐开发者在 onStartSuccess 回调后开始拉广告
                    Log.e("gdt onStartSuccess", "加载成功")
                }

                override fun onStartFailed(e: Exception) {
                    Log.e("gdt onStartFailed:", e.toString())
                }
            }
        )
        result.success(true)
    }

    /**
     * 设置广告个性化
     * @param call   MethodCall
     * @param result Result
     */
    private fun setPersonalizedState(call: MethodCall, result: MethodChannel.Result) {
        val state = call.argument<Int>("state")!!
        setPersonalizedState(state)
        result.success(true);
    }

    /**
     * 开屏广告
     * @param call   MethodCall
     * @param result Result
     */
    private fun showSplashAd(call: MethodCall, result: MethodChannel.Result) {
        val posId: String? = call.argument(UnionADConfig.KEY_POSID)
        val logo: String? = call.argument(UnionADConfig.KEY_LOGO)
        val fetchDelay: Double = call.argument(UnionADConfig.KEY_FETCH_DELAY)!!
        val intent = Intent(activity, AdSplashActivity::class.java)
        intent.putExtra(UnionADConfig.KEY_POSID, posId)
        intent.putExtra(UnionADConfig.KEY_LOGO, logo)
        intent.putExtra(UnionADConfig.KEY_FETCH_DELAY, fetchDelay)
        activity.startActivity(intent)
        result.success(true)
    }

}
