package com.example.union_ad_ssgf.page

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.view.View
import android.widget.FrameLayout
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.example.union_ad_ssgf.PluginDelegate
import com.example.union_ad_ssgf.config.UnionADConfig
import com.example.union_ad_ssgf.event.AdEventAction
import com.example.union_ad_ssgf.load.FeedAdManager
import com.qq.e.ads.nativ.NativeExpressADView
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.platform.PlatformView

class AdFeedView(
        context: Context,
        private var id: Int,
        private var creationParams: Map<String, Any>?,
        private var pluginDelegate: PluginDelegate?
) : BaseAdPage(), PlatformView {
    private var frameLayout = FrameLayout(context)
    private var fad: NativeExpressADView? = null
    private var receiver: BroadcastReceiver? = null

    init {
        val call = MethodCall("AdFeedView", creationParams)
        showAd(this.pluginDelegate!!.activity, id, call)
    }

    override fun loadAd(call: MethodCall?) {
        val key = adId!!.toInt()
        regReceiver(key)
        fad = FeedAdManager.getInstance()!!.getAd(key)
        if (fad != null) {
            if (frameLayout.childCount > 0) {
                frameLayout.removeAllViews()
            }
            fad!!.render()
            frameLayout.addView(fad)
        }
    }

    override fun getView(): View? {
        return frameLayout
    }

    override fun dispose() {
        removeAd()
    }

    /**
     * 注册广播
     * @param key key
     */
    private fun regReceiver(key: Int) {
        // 注册广播
        receiver =
                object : BroadcastReceiver() {
                    override fun onReceive(context: Context, intent: Intent) {
                        val event = intent.getStringExtra("event")
                        sendEvent(event)
                        if (AdEventAction.onAdClosed == event || AdEventAction.onAdError == event) {
                            this@AdFeedView.disposeAd()
                        }
                    }
                }
        val intentFilter = IntentFilter(UnionADConfig.KEY_FEED_VIEW + "_" + key)
        LocalBroadcastManager.getInstance(activity!!).registerReceiver(receiver!!, intentFilter)
    }

    /** 移除广告 */
    private fun removeAd() {
        frameLayout!!.removeAllViews()
        // 注销广播
        if (receiver != null) {
            LocalBroadcastManager.getInstance(activity!!).unregisterReceiver(receiver!!)
        }
    }

    /** 销毁广告 */
    private fun disposeAd() {
        removeAd()
        FeedAdManager.getInstance()!!.removeAd(adId!!.toInt())
        if (fad != null) {
            fad!!.destroy()
        }
    }
}
