package com.example.union_ad_ssgf.page

import android.annotation.SuppressLint
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.KeyEvent
import android.view.View
import android.widget.FrameLayout
import androidx.appcompat.app.AppCompatActivity
import androidx.appcompat.widget.AppCompatImageView
import com.example.union_ad_ssgf.R
import com.example.union_ad_ssgf.config.UnionADConfig
import com.example.union_ad_ssgf.event.AdErrorEvent
import com.example.union_ad_ssgf.event.AdEvent
import com.example.union_ad_ssgf.event.AdEventAction
import com.example.union_ad_ssgf.event.AdEventHandler
import com.qq.e.ads.splash.SplashAD
import com.qq.e.ads.splash.SplashADListener
import com.qq.e.comm.util.AdError


/**
 * 开屏广告
 */
class AdSplashActivity() : AppCompatActivity(), SplashADListener {
    private val TAG = AdSplashActivity::class.java.getSimpleName()

    // 广告容器
    private var ad_container: FrameLayout? = null

    // 自定义品牌 logo
    private var ad_logo: AppCompatImageView? = null

    // 广告位 id
    private var posId: String? = null

    // 是否全屏
    private var isFullScreen = false

    // 开屏广告
    private var splashAD: SplashAD? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_ad_splash);
        initView();
        initData();
    }

    /**
     * 初始化View
     */
    private fun initView() {
        ad_container = findViewById<FrameLayout>(R.id.splash_ad_container)
        ad_logo = findViewById<AppCompatImageView>(R.id.splash_ad_logo)
    }

    /**
     * 初始化数据
     */
    private fun initData() {
        // 获取参数
        posId = intent.getStringExtra(UnionADConfig.KEY_POSID)
        val logo = intent.getStringExtra(UnionADConfig.KEY_LOGO)
        val fetchDelay = intent.getDoubleExtra(UnionADConfig.KEY_FETCH_DELAY, 0.0)
        val absFetchDelay = (fetchDelay * 1000).toInt()
        isFullScreen = TextUtils.isEmpty(logo)
        // 创建开屏广告
        splashAD = SplashAD(this, posId, this, absFetchDelay)
        if (isFullScreen) {
            // logo 为空则加载全屏广告
            ad_logo!!.setVisibility(View.GONE)
            splashAD!!.fetchFullScreenAdOnly()
        } else {
            // 加载 logo
            val resId: Int = getMipmapId(logo!!)
            if (resId > 0) {
                ad_logo!!.setVisibility(View.VISIBLE)
                ad_logo!!.setImageResource(resId)
            }
            // 加载广告
            splashAD!!.fetchAdOnly()
        }
    }

    override fun onADDismissed() {
        Log.d(TAG, "onADDismissed")
        finishPage()
        AdEventHandler.getInstance()?.sendEvent(AdEvent(posId, "", 1, AdEventAction.onAdClosed));
    }

    override fun onNoAD(adError: AdError) {
        Log.d(TAG, "onNoAD adError:" + adError.errorMsg);
        finishPage()
        AdEventHandler.getInstance()!!
            .sendEvent(AdErrorEvent(posId, "", 1, adError.errorCode, adError.errorMsg));
    }

    override fun onADPresent() {
        Log.d(TAG, "onADPresent")
        AdEventHandler.getInstance()!!.sendEvent(AdEvent(posId, "", 1, AdEventAction.onAdPresent))
    }

    override fun onADClicked() {
        Log.d(TAG, "onADClicked")
        AdEventHandler.getInstance()!!.sendEvent(AdEvent(posId, "", 1, AdEventAction.onAdClicked))
    }

    override fun onADTick(millisUntilFinished: Long) {
        Log.d(TAG, "onADTick millisUntilFinished：$millisUntilFinished");
    }

    override fun onADExposure() {
        Log.d(TAG, "onADExposure")
        AdEventHandler.getInstance()!!.sendEvent(AdEvent(posId, "", 1, AdEventAction.onAdExposure))
    }

    override fun onADLoaded(expireTimestamp: Long) {
        Log.d(TAG, "onADLoaded expireTimestamp：$expireTimestamp")
        AdEventHandler.getInstance()!!.sendEvent(AdEvent(posId, "", 1, AdEventAction.onAdLoaded))
        if (isFullScreen) {
            splashAD!!.showFullScreenAd(ad_container)
        } else {
            splashAD!!.showAd(ad_container)
        }
    }

    /**
     * 完成广告，退出开屏页面
     */
    private fun finishPage() {
        finish()
        // 设置退出动画
        overridePendingTransition(0, android.R.anim.fade_out)
    }

    /**
     * 开屏页一定要禁止用户对返回按钮的控制，否则将可能导致用户手动退出了App而广告无法正常曝光和计费
     */
    override fun onKeyDown(keyCode: Int, event: KeyEvent?): Boolean {
        return if (keyCode == KeyEvent.KEYCODE_BACK || keyCode == KeyEvent.KEYCODE_HOME) {
            true
        } else super.onKeyDown(keyCode, event)
    }

    /**
     * 获取图片资源的id
     *
     * @param resName 资源名称，不带后缀
     * @return 返回资源id
     */
    @SuppressLint("DiscouragedApi")
    private fun getMipmapId(resName: String): Int {
        return getResources().getIdentifier(resName, "mipmap", packageName)
    }
}